==> 1.14.514.131-1.21.4.tar.gz: serverplayeronlinetracker/src/main/java/com/example/playertime/ModConfig.java <==
package com.example.playertime;

import com.google.gson.*;
import java.io.*;
import java.nio.file.*;

public class ModConfig {
    private static final Gson GSON = new GsonBuilder().setPrettyPrinting().create();
    private final Path configPath;
    private int webPort = 60048;
    private String language = "zh_cn";
    private long autoSaveSeconds = 300;

    public ModConfig(Path configDir) {
        this.configPath = configDir.resolve("playertime-config.json");
        loadConfig();
    }

    private void loadConfig() {
        if (!Files.exists(configPath)) {
            PlayerTimeMod.LOGGER.info("[在线时间] 配置文件未找到，正在创建默认配置");
            saveConfig();
            return;
        }

        try (Reader reader = Files.newBufferedReader(configPath)) {
            JsonElement jsonElement = JsonParser.parseReader(reader);

            if (jsonElement == null || !jsonElement.isJsonObject()) {
                PlayerTimeMod.LOGGER.warn("[在线时间] 配置文件为空或格式错误，正在使用默认配置并覆盖");
                saveConfig();
                return;
            }

            JsonObject json = jsonElement.getAsJsonObject();

            if (json.has("webPort")) {
                webPort = json.get("webPort").getAsInt();
            } else {
                PlayerTimeMod.LOGGER.info("[在线时间] 配置文件缺少“webPort”字段，添加默认值'%s'并保存", webPort);
                saveConfig();
            }
            if (json.has("language")) {
                language = json.get("language").getAsString();
            } else {
                PlayerTimeMod.LOGGER.info("[在线时间] 配置文件缺少“language”字段，添加默认值'%s'并保存", language);
                saveConfig();
            }
            if (json.has("autoSaveSeconds")) {
                autoSaveSeconds = json.get("autoSaveSeconds").getAsLong();
            } else {
                PlayerTimeMod.LOGGER.info("[在线时间] 配置文件缺少“autoSaveSeconds”字段，添加默认值'%s'并保存", autoSaveSeconds);
                saveConfig();
            }

        } catch (Exception e) {
            PlayerTimeMod.LOGGER.error("[在线时间] 加载配置文件失败，使用默认配置", e);
            saveConfig();
        }
    }

    // 保存配置
    private void saveConfig() {
        JsonObject json = new JsonObject();
        json.addProperty("webPort", webPort);
        json.addProperty("language", language);
        json.addProperty("autoSaveSeconds", autoSaveSeconds);

        try {
            Files.createDirectories(configPath.getParent());
            try (Writer writer = Files.newBufferedWriter(configPath)) {
                GSON.toJson(json, writer);
            }
            PlayerTimeMod.LOGGER.info("[在线时间] 配置已成功保存");
        } catch (Exception e) {
            PlayerTimeMod.LOGGER.error("[在线时间] 保存配置失败", e);
        }
    }

    // 获取端口
    public int getWebPort() {
        return webPort;
    }

    // 获取语言
    public String getLanguage() {
        return language;
    }

    // 获取保存间隔
    public long getSeconds() {
        return autoSaveSeconds;
    }
}

==> 1.14.514.134.tar.gz: serverplayeronlinetracker/src/main/java/com/example/playertime/ModConfig.java <==
package com.example.playertime;

import com.google.gson.*;
import java.io.*;
import java.nio.file.*;

public class ModConfig {
    private static final Gson GSON = new GsonBuilder().setPrettyPrinting().create();
    private final Path configPath;
    private int webPort = 60048;
    private String language = "zh_cn";

    public ModConfig(Path configDir) {
        this.configPath = configDir.resolve("playertime-config.json");
        loadConfig();
    }

    private void loadConfig() {
        if (!Files.exists(configPath)) {
            PlayerTimeMod.LOGGER.info("[在线时间] 配置文件未找到，正在创建默认配置");
            saveConfig();
            return;
        }

        try (Reader reader = Files.newBufferedReader(configPath)) {
            JsonElement jsonElement = JsonParser.parseReader(reader);

            if (jsonElement == null || !jsonElement.isJsonObject()) {
                PlayerTimeMod.LOGGER.warn("[在线时间] 配置文件为空或格式错误，正在使用默认配置并覆盖");
                saveConfig();
                return;
            }

            JsonObject json = jsonElement.getAsJsonObject();

            if (json.has("webPort")) {
                webPort = json.get("webPort").getAsInt();
            } else {
                PlayerTimeMod.LOGGER.info("[在线时间] 配置文件缺少webPort字段，添加默认值'%s'并保存", webPort);
                saveConfig();
            }
            if (json.has("language")) {
                language = json.get("language").getAsString();
            } else {
                PlayerTimeMod.LOGGER.info("[在线时间] 配置文件缺少language字段，添加默认值'%s'并保存", language);
                saveConfig();
            }

        } catch (Exception e) {
            PlayerTimeMod.LOGGER.error("[在线时间] 加载配置文件失败，使用默认配置", e);
            saveConfig();
        }
    }

    // 保存配置
    private void saveConfig() {
        JsonObject json = new JsonObject();
        json.addProperty("webPort", webPort);
        json.addProperty("language", language);

        try {
            Files.createDirectories(configPath.getParent());
            try (Writer writer = Files.newBufferedWriter(configPath)) {
                GSON.toJson(json, writer);
            }
            PlayerTimeMod.LOGGER.info("[在线时间] 配置已成功保存");
        } catch (Exception e) {
            PlayerTimeMod.LOGGER.error("[在线时间] 保存配置失败", e);
        }
    }

    // 获取端口
    public int getWebPort() {
        return webPort;
    }

    // 获取语言
    public String getLanguage() {
        return language;
    }
}
